<?xml version="1.0" encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:lxslt="http://xml.apache.org/xslt"
	xmlns:redirect="http://xml.apache.org/xalan/redirect"
    extension-element-prefixes="redirect">


<xsl:template match="IntegratedAnalysis" mode="scorecard-system-specific">

	<xsl:variable name="packages-element" select="Packages"/>

   	<html>
      <head>
         <link rel="stylesheet" type="text/css" href="stylesheet.css"/>
      </head>
      <body>

         <xsl:call-template name="page-header">
  	  	   <xsl:with-param name="main-menu-page-name" select="'scorecard'"/>
  	  	   <xsl:with-param name="page-name" select="'system specific'"/>
  	  	   <xsl:with-param name="root-element" select="current()"/>
  	     </xsl:call-template>

		<hr size="1"/>
		<br/>
		No extra analysis for this system. Here you may include yor own.

      </body>
   </html>

</xsl:template>



<xsl:template name="metric-header-system-specific">
	<xsl:param name="header-name"/>
	<xsl:param name="single-package"/>
	<xsl:param name="row-type"/>

	<tr>
       <th><xsl:value-of select="$header-name"/></th>

       <xsl:choose>

	       <xsl:when test="$row-type='system-specific'">
	   			<th>Components</th>
				<th>Service Methods</th>
				<th>Serv. Meth. per Comp</th>
				<th>% Called Serv. Methods</th>
				<th>Number of calls</th>
				<th>% Func. errors per calls</th>
				<th>% Tech. errors per calls</th>
				<th>Avg. resp. time (ms)</th>
				<th>Change CRs</th>
				<th>Error CRs</th>
				<th>Unknown CRs</th>
	       </xsl:when>

	       <xsl:when test="$row-type='sql-metrics'">
	   			<xsl:if test="not($single-package='true')">
		       	<th>Total Packages</th>
		       	</xsl:if>
		       	<th>Total Scripts</th>
		       	<th>Procedures</th>
		       	<th>Source Statements</th>
		       	<th>Cyclomatic Complexity</th>
		       	<th>Cmplx. per Stmnt.</th>
		       	<th>Cmplx. per Proc.</th>
		       	<th>Errors</th>
	       </xsl:when>

	  </xsl:choose>
    </tr>
</xsl:template>

<xsl:template name="metric-rows-system-specific">
	<xsl:param name="packages-element"/>
	<xsl:param name="row-type"/>

	<xsl:for-each select="$radar-config-doc/radar-config/subsystems/subsystem">
		<xsl:variable name="subsystem-name" select="normalize-space(name)"/>
		<xsl:choose>
			<xsl:when test="$row-type='sql-metrics'">
				<xsl:variable name="file-name" select="concat($subsystem-name,'-subsystem-sql-summary.html')"/>
				<xsl:call-template name="subsystem-sql-detail">
					<xsl:with-param name="total-packages" select="count($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/sql-metrics)"/>
					<xsl:with-param name="source-statements-in-subsystem" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/sql-metrics/ncss)"/>
					<xsl:with-param name="procedures-in-subsystem" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/sql-metrics/procedures)"/>
					<xsl:with-param name="cyclomatic-complexity-in-subsystem" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/sql-metrics/ccn)"/>
					<xsl:with-param name="total-errors" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/sql-metrics/errors)"/>
					<xsl:with-param name="total-scripts" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/sql-metrics/scripts)"/>
					<xsl:with-param name="total-procedures" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/sql-metrics/procedures)"/>
					<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
					<xsl:with-param name="subsystem-link" select="$file-name"/>
				</xsl:call-template>

				<redirect:write file="{$file-name}">
			    	<xsl:call-template name="sql-subsystem-packages">
			    		<xsl:with-param name="packages-element" select="$packages-element"/>
						<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			    	</xsl:call-template>
		   		</redirect:write>
			</xsl:when>

			<xsl:when test="$row-type='system-specific'">
				<xsl:variable name="file-name" select="concat($subsystem-name,'-subsystem-system-specific-summary.html')"/>
				<xsl:call-template name="subsystem-system-specific-detail">
					<xsl:with-param name="components" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/component-metrics/components)"/>
					<xsl:with-param name="calls" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/component-metrics/calls)"/>
					<xsl:with-param name="methods" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/component-metrics/methods)"/>
					<xsl:with-param name="called-methods" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/component-metrics/called-methods)"/>
					<xsl:with-param name="func-errors" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/component-metrics/func-errors)"/>
					<xsl:with-param name="tech-errors" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/component-metrics/tech-errors)"/>
					<xsl:with-param name="total-avg-resp-time" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/component-metrics[not(avg-resp-time = 'NaN')]/avg-resp-time)"/>
					<xsl:with-param name="count-avg-resp-time" select="count($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/component-metrics[not(avg-resp-time='0')])"/>
					<xsl:with-param name="total-change-crs" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/cr-activity/change-cr)"/>
					<xsl:with-param name="total-error-crs"  select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/cr-activity/error-cr)"/>
					<xsl:with-param name="total-unknown-crs" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/cr-activity/unknown-cr)"/>
					<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
					<xsl:with-param name="subsystem-link" select="$file-name"/>
				</xsl:call-template>
				<redirect:write file="{$file-name}">
			    	<xsl:call-template name="system-specific-subsystem-packages">
			    		<xsl:with-param name="packages-element" select="$packages-element"/>
						<xsl:with-param name="subsystem-name" select="normalize-space(name)"/>
			    	</xsl:call-template>
		   		</redirect:write>
			</xsl:when>
		</xsl:choose>
	</xsl:for-each>
</xsl:template>

<xsl:template name="sql-subsystem-packages">
	<xsl:param name="packages-element"/>
	<xsl:param name="subsystem-name"/>

	<html>
      <head>
         <link rel="stylesheet" type="text/css" href="stylesheet.css"/>
      </head>
      <body>

         <xsl:call-template name="page-header">
  	  	   <xsl:with-param name="page-name" select="concat('Packages with SQL : ',$subsystem-name)"/>
  	  	   <xsl:with-param name="main-menu-page-name" select="'scorecard'"/>
  	  	   <xsl:with-param name="path-to-root" select="''"/>
  	     </xsl:call-template>


		<table width="100%" class="details">
			<xsl:call-template name="metric-header-system-specific">
				<xsl:with-param name="header-name" select="concat('Packages in ',$subsystem-name)"/>
				<xsl:with-param name="single-package" select="'true'"/>
				<xsl:with-param name="row-type" select="'sql-metrics'"/>
	    	</xsl:call-template>

			<xsl:for-each select="$packages-element/Package[(Stats/sql-metrics) and (subsystem/@name=$subsystem-name)]">
				<xsl:call-template name="subsystem-sql-detail">
					<xsl:with-param name="total-packages" select="Stats/sql-metrics"/>
					<xsl:with-param name="source-statements-in-subsystem" select="Stats/sql-metrics/ncss"/>
					<xsl:with-param name="procedures-in-subsystem" select="Stats/sql-metrics/procedures"/>
					<xsl:with-param name="cyclomatic-complexity-in-subsystem" select="Stats/sql-metrics/ccn"/>
					<xsl:with-param name="total-errors" select="Stats/sql-metrics/errors"/>
					<xsl:with-param name="total-scripts" select="Stats/sql-metrics/scripts"/>
					<xsl:with-param name="total-procedures" select="Stats/sql-metrics/procedures"/>
					<xsl:with-param name="single-package" select="'true'"/>
					<xsl:with-param name="subsystem-name" select="@name"/>
					<xsl:with-param name="subsystem-link" select="concat('overview-packages.html#PK',@name)"/>
				</xsl:call-template>
			</xsl:for-each>


		</table>
      </body>
   </html>
</xsl:template>


<xsl:template name="system-specific-subsystem-packages">
	<xsl:param name="packages-element"/>
	<xsl:param name="subsystem-name"/>

	<html>
      <head>
         <link rel="stylesheet" type="text/css" href="stylesheet.css"/>
      </head>
      <body>

         <xsl:call-template name="page-header">
  	  	   <xsl:with-param name="page-name" select="concat('Packages : ',$subsystem-name)"/>
  	  	   <xsl:with-param name="main-menu-page-name" select="'scorecard'"/>
  	  	   <xsl:with-param name="path-to-root" select="''"/>
  	     </xsl:call-template>

		<table width="100%" class="details">
			<xsl:call-template name="metric-header-system-specific">
				<xsl:with-param name="header-name" select="concat('Packages in ',$subsystem-name)"/>
				<xsl:with-param name="single-package" select="'true'"/>
				<xsl:with-param name="row-type" select="'system-specific'"/>
	    	</xsl:call-template>

			<xsl:for-each select="$packages-element/Package[(Stats/component-metrics) and (subsystem/@name=$subsystem-name)]">
				<xsl:call-template name="subsystem-system-specific-detail">
					<xsl:with-param name="components" select="Stats/component-metrics/components"/>
					<xsl:with-param name="calls" select="Stats/component-metrics/calls"/>
					<xsl:with-param name="methods" select="Stats/component-metrics/methods"/>
					<xsl:with-param name="called-methods" select="Stats/component-metrics/called-methods"/>
					<xsl:with-param name="func-errors" select="Stats/component-metrics/func-errors"/>
					<xsl:with-param name="tech-errors" select="Stats/component-metrics/tech-errors"/>
					<xsl:with-param name="total-avg-resp-time" select="Stats/component-metrics/avg-resp-time"/>
					<xsl:with-param name="count-avg-resp-time" select="count(Stats/component-metrics[not(avg-resp-time='0')])"/>
					<xsl:with-param name="total-change-crs" select="Stats/cr-activity/change-cr"/>
					<xsl:with-param name="total-error-crs"  select="Stats/cr-activity/error-cr"/>
					<xsl:with-param name="total-unknown-crs" select="Stats/cr-activity/unknown-cr"/>
					<xsl:with-param name="single-package" select="'true'"/>
					<xsl:with-param name="subsystem-name" select="@name"/>
					<xsl:with-param name="subsystem-link" select="concat('overview-packages.html#PK',@name)"/>
				</xsl:call-template>
			</xsl:for-each>
		</table>
      </body>
   </html>

</xsl:template>



<xsl:template name="subsystem-sql-detail">
	<xsl:param name="subsystem-name"/>
	<xsl:param name="subsystem-link"/>
	<xsl:param name="single-package"/>
	<xsl:param name="total-packages"/>
	<xsl:param name="source-statements-in-subsystem"/>
	<xsl:param name="procedures-in-subsystem"/>
	<xsl:param name="cyclomatic-complexity-in-subsystem"/>
	<xsl:param name="total-errors"/>
	<xsl:param name="total-scripts"/>
	<xsl:param name="total-procedures"/>

	<tr>
	 <td align="left">
	    <a href="{$subsystem-link}">
	       <xsl:value-of select="$subsystem-name"/>
	    </a>
	 </td>
	 <xsl:if test="not($single-package='true')">
       	<td align="right"><xsl:value-of select="$total-packages"/></td>
     </xsl:if>
	 <td align="right"><xsl:value-of select="$total-scripts"/></td>
	 <td align="right"><xsl:value-of select="$total-procedures"/></td>
	 <td align="right"><xsl:value-of select="$source-statements-in-subsystem"/></td>
	 <td align="right"><xsl:value-of select="$cyclomatic-complexity-in-subsystem"/></td>
	 <td align="right">
	 <xsl:choose>
	 	<xsl:when test="$source-statements-in-subsystem=0">
			0
	 	</xsl:when>
	 	<xsl:otherwise>
	 		<xsl:value-of select="format-number($cyclomatic-complexity-in-subsystem div $source-statements-in-subsystem, '#.##')"/>
	 	</xsl:otherwise>
	 </xsl:choose>
	 </td>
	 <td align="right">
	 <xsl:choose>
	 	<xsl:when test="$procedures-in-subsystem='0'">
			0
	 	</xsl:when>
	 	<xsl:otherwise>
	 		<xsl:value-of select="format-number($cyclomatic-complexity-in-subsystem div $procedures-in-subsystem, '#.##')"/>
	 	</xsl:otherwise>
	 </xsl:choose>
	 </td>
	 <td align="right">
	 <xsl:choose>
	 	<xsl:when test="$total-errors &gt; 0">
			<xsl:value-of select="$total-errors"/>
	 	</xsl:when>
	 	<xsl:otherwise>
	 		0
	 	</xsl:otherwise>
	 </xsl:choose>
	 </td>
	</tr>
</xsl:template>


<xsl:template name="subsystem-system-specific-detail">
	<xsl:param name="components"/>
	<xsl:param name="calls"/>
	<xsl:param name="methods"/>
	<xsl:param name="called-methods"/>
	<xsl:param name="func-errors"/>
	<xsl:param name="tech-errors"/>
	<xsl:param name="total-avg-resp-time"/>
	<xsl:param name="count-avg-resp-time"/>
	<xsl:param name="total-change-crs"/>
	<xsl:param name="total-error-crs"/>
	<xsl:param name="total-unknown-crs"/>
	<xsl:param name="subsystem-name"/>
	<xsl:param name="subsystem-link"/>
	<xsl:param name="single-package"/>

	<tr>
	 <td align="left">
	    <a href="{$subsystem-link}">
	       <xsl:value-of select="$subsystem-name"/>
	    </a>
	 </td>


     <td align="right"><xsl:value-of select="$components"/></td>
     <td align="right"><xsl:value-of select="$methods"/></td>
     <td align="right"><xsl:value-of select="format-number($methods div $components, '#.##')"/></td>
     <td align="right"><xsl:value-of select="format-number(100 * $called-methods div $methods, '#.##')"/> %</td>
	 <td align="right"><xsl:value-of select="$calls"/></td>
	 <td align="right"><xsl:value-of select="format-number(100 * $func-errors div $calls, '#.##')"/> %</td>
	 <td align="right"><xsl:value-of select="format-number(100 * $tech-errors div $calls, '#.##')"/> %</td>
	 <td align="right"><xsl:value-of select="format-number($total-avg-resp-time div $count-avg-resp-time, '#.##')"/></td>
	 <td align="right"><xsl:value-of select="$total-change-crs"/></td>
	 <td align="right"><xsl:value-of select="$total-error-crs"/></td>
	 <td align="right"><xsl:value-of select="$total-unknown-crs"/></td>
	</tr>
</xsl:template>


</xsl:stylesheet>
